@@ -2,7 +2,6 @@ package Data::Generator::FromDDL;
 use 5.008005;
 use strict;
 use warnings;
-use SQL::Translator;
 use Class::Accessor::Lite (
     new => 1,
     rw => [qw(builder_class parser ddl include exclude)],
@@ -10,40 +9,35 @@ use Class::Accessor::Lite (
 
 use Data::Generator::FromDDL::Director;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub generate {
     my ($self, $num, $out_fh, $format, $pretty, $bytes_per_sql) = @_;
+
+    # set default values if not specified
     my $builder_class = $self->builder_class
         || 'Data::Generator::FromDDL::Builder::SerialOrder';
+    my $parser = $self->parser || 'mysql';
+    my $include = $self->include || [];
+    my $exclude = $self->exclude || [];
+    my $ddl = $self->ddl || '';
+    $out_fh ||= *STDOUT;
     $format ||= 'sql';
     $bytes_per_sql ||= 1024 * 1024; # 1MB;
 
     my $director = Data::Generator::FromDDL::Director->new({
         builder_class => $builder_class,
-        parser => $self->parser || 'mysql',
-        ddl => $self->ddl,
-        include => $self->include || [],
-        exclude => $self->exclude || [],
+        parser => $parser,
+        ddl => $ddl,
+        include => $include,
+        exclude => $exclude,
+        out_fh => $out_fh,
     });
+
     my @recordsets = $director->generate($num);
-
-    my $output = do {
-        my $formatter;
-        if (lc($format) eq 'json') {
-            $formatter = 'to_json';
-        } elsif (lc($format) eq 'yaml') {
-            $formatter = 'to_yaml';
-        } else {
-            $formatter = 'to_sql';
-        }
-        join "\n", map {
-            $_->$formatter($pretty, $bytes_per_sql)
-        } @recordsets;
-    };
-
-    $out_fh ||= *STDOUT;
-    print $out_fh $output . "\n";
+    $director->flush(
+        \@recordsets, $out_fh, $format, $pretty, $bytes_per_sql
+    );
 }
 
 
@@ -64,7 +58,7 @@ Data::Generator::FromDDL - Dummy data generator from DDL statements
         ddl => 'CREATE TABLE users (....);',
         parser => 'mysql',
     });
-    $generator->generate(100);
+    $generator->generate(100); # Generated data are written to STDOUT.
 
 =head1 DESCRIPTION
 
@@ -146,7 +140,7 @@ File handle object to which records are dumped.
 
 =item $format (default: 'sql')
 
-Output format. Choices are B<'sql'>, B<'json'>, B<'yaml'>.
+Output format. Choices are B<'sql'> or B<'json'>.
 
 =item $pretty (default: false)
 
